@@ -39,12 +39,12 @@ check_variables.moderated_mediation <- function(model) {
   if (length(Var_n_check) != 0) {
     message("\nMessage:")
     message(
-"It appears that the following variables are not contrast-coded or centered, 
-please make sure it is intended as regression coefficients depends on the 
+"It appears that the following variables are not contrast-coded or centered,
+please make sure it is intended as regression coefficients depends on the
 variables' coding:"
     )
     for (var in Var_n_check) {
-      message(glue::glue("* {var}"))
+      message(glue("* {var}"))
     }
   }
 }
